Stan Math Library: stan/math/rev/mat/fun/trace_gen_inv_quad_form_ldlt.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
trace_gen_inv_quad_form_ldlt.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/prim/scal/meta/is_var.hpp>`
`#include <stan/math/rev/scal/meta/is_var.hpp>`
`#include <boost/utility/enable_if.hpp>`
`#include <stan/math/prim/mat/err/check_multiplicable.hpp>`
`#include <stan/math/prim/mat/err/check_square.hpp>`
`#include <stan/math/rev/mat/fun/trace_inv_quad_form_ldlt.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , int R1, int C1, typename T2 , int R2, int C2, typename T3 , int R3, int C3>
boost::enable_if_c< stan::is_var< T1 >::value||stan::is_var< T2 >::value||stan::is_var< T3 >::value, var >::type | stan::math::trace_gen_inv_quad_form_ldlt (const Eigen::Matrix< T1, R1, C1 > &D, const stan::math::LDLT_factor< T2, R2, C2 > &A, const Eigen::Matrix< T3, R3, C3 > &B)
| Compute the trace of an inverse quadratic form. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.